==> jc-1.4.0.tar.gz: gnu/regexp/RETokenWordBoundary.h <==
// final class gnu.regexp.RETokenWordBoundary

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class 53f0ba217609c27c gnu_regexp_RETokenWordBoundary
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenWordBoundary_H_
#define _JC_gnu_regexp_RETokenWordBoundary_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenWordBoundary$sub_refs	_jc_gnu_regexp_RETokenWordBoundary$sub_refs;
typedef struct _jc_gnu_regexp_RETokenWordBoundary$sub_nonrefs	_jc_gnu_regexp_RETokenWordBoundary$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenWordBoundary$refs	_jc_gnu_regexp_RETokenWordBoundary$refs;
typedef struct _jc_gnu_regexp_RETokenWordBoundary$nonrefs	_jc_gnu_regexp_RETokenWordBoundary$nonrefs;
typedef struct _jc_gnu_regexp_RETokenWordBoundary$object	_jc_gnu_regexp_RETokenWordBoundary$object;

typedef struct _jc_gnu_regexp_RETokenWordBoundary$fields_struct	_jc_gnu_regexp_RETokenWordBoundary$fields_struct;
typedef const struct _jc_gnu_regexp_RETokenWordBoundary$vmethods	_jc_gnu_regexp_RETokenWordBoundary$vmethods;
typedef const struct _jc_gnu_regexp_RETokenWordBoundary$vtable	_jc_gnu_regexp_RETokenWordBoundary$vtable;
typedef const struct _jc_gnu_regexp_RETokenWordBoundary$vtype	_jc_gnu_regexp_RETokenWordBoundary$vtype;

// Class fields structure
struct _jc_gnu_regexp_RETokenWordBoundary$fields_struct {
	jint	BEGIN;
	jint	END;
};
extern _jc_gnu_regexp_RETokenWordBoundary$fields_struct _jc_gnu_regexp_RETokenWordBoundary$class_fields;

// Constructors
extern void _jc_gnu_regexp_RETokenWordBoundary$method$_init$aabfffe230c84c7b(_jc_env *, struct _jc_gnu_regexp_RETokenWordBoundary$object *, jint, jint, jboolean);

// Virtual methods
extern void _jc_gnu_regexp_RETokenWordBoundary$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenWordBoundary$object *, struct _jc_java_lang_StringBuffer$object *);
extern jboolean _jc_gnu_regexp_RETokenWordBoundary$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenWordBoundary$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenWordBoundary$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenWordBoundary$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenWordBoundary$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenWordBoundary$object *, struct _jc_java_lang_StringBuffer$object *);
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenWordBoundary$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
};

// Vtable
struct _jc_gnu_regexp_RETokenWordBoundary$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenWordBoundary$vmethods	gnu_regexp_RETokenWordBoundary;
};

// Vtype
struct _jc_gnu_regexp_RETokenWordBoundary$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenWordBoundary$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenWordBoundary$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenWordBoundary$refs {
    _jc_gnu_regexp_RETokenWordBoundary$sub_refs	gnu_regexp_RETokenWordBoundary;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenWordBoundary$sub_nonrefs {
	jboolean	negated;
	jint	where;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenWordBoundary$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenWordBoundary$sub_nonrefs	gnu_regexp_RETokenWordBoundary;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenWordBoundary$object {
	_jc_gnu_regexp_RETokenWordBoundary$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenWordBoundary$vtype	*vtype;
	_jc_gnu_regexp_RETokenWordBoundary$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenWordBoundary$vtype _jc_gnu_regexp_RETokenWordBoundary$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenWordBoundary, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenWordBoundary$class_object;

#endif	/* _JC_gnu_regexp_RETokenWordBoundary_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/RETokenWordBoundary.h <==
// final class gnu.regexp.RETokenWordBoundary

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class 53f0ba217609c27c gnu_regexp_RETokenWordBoundary
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenWordBoundary_H_
#define _JC_gnu_regexp_RETokenWordBoundary_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenWordBoundary$sub_refs	_jc_gnu_regexp_RETokenWordBoundary$sub_refs;
typedef struct _jc_gnu_regexp_RETokenWordBoundary$sub_nonrefs	_jc_gnu_regexp_RETokenWordBoundary$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenWordBoundary$refs	_jc_gnu_regexp_RETokenWordBoundary$refs;
typedef struct _jc_gnu_regexp_RETokenWordBoundary$nonrefs	_jc_gnu_regexp_RETokenWordBoundary$nonrefs;
typedef struct _jc_gnu_regexp_RETokenWordBoundary$object	_jc_gnu_regexp_RETokenWordBoundary$object;

typedef struct _jc_gnu_regexp_RETokenWordBoundary$fields_struct	_jc_gnu_regexp_RETokenWordBoundary$fields_struct;
typedef const struct _jc_gnu_regexp_RETokenWordBoundary$vmethods	_jc_gnu_regexp_RETokenWordBoundary$vmethods;
typedef const struct _jc_gnu_regexp_RETokenWordBoundary$vtable	_jc_gnu_regexp_RETokenWordBoundary$vtable;
typedef const struct _jc_gnu_regexp_RETokenWordBoundary$vtype	_jc_gnu_regexp_RETokenWordBoundary$vtype;

// Class fields structure
struct _jc_gnu_regexp_RETokenWordBoundary$fields_struct {
	jint	BEGIN;
	jint	END;
};
extern _jc_gnu_regexp_RETokenWordBoundary$fields_struct _jc_gnu_regexp_RETokenWordBoundary$class_fields;

// Constructors
extern void _jc_gnu_regexp_RETokenWordBoundary$method$_init$aabfffe230c84c7b(_jc_env *, struct _jc_gnu_regexp_RETokenWordBoundary$object *, jint, jint, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_regexp_RETokenWordBoundary$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenWordBoundary$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RETokenWordBoundary$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenWordBoundary$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenWordBoundary$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenWordBoundary$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenWordBoundary$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenWordBoundary$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenWordBoundary$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_RETokenWordBoundary$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenWordBoundary$vmethods	gnu_regexp_RETokenWordBoundary;
};

// Vtype
struct _jc_gnu_regexp_RETokenWordBoundary$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenWordBoundary$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenWordBoundary$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenWordBoundary$refs {
    _jc_gnu_regexp_RETokenWordBoundary$sub_refs	gnu_regexp_RETokenWordBoundary;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenWordBoundary$sub_nonrefs {
	jboolean	negated;
	jint	where;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenWordBoundary$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenWordBoundary$sub_nonrefs	gnu_regexp_RETokenWordBoundary;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenWordBoundary$object {
	_jc_gnu_regexp_RETokenWordBoundary$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenWordBoundary$vtype	*vtype;
	_jc_gnu_regexp_RETokenWordBoundary$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenWordBoundary$vtype _jc_gnu_regexp_RETokenWordBoundary$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenWordBoundary, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenWordBoundary$class_object;

#endif	/* _JC_gnu_regexp_RETokenWordBoundary_H_ */
